@@ -267,8 +267,7 @@ class RequestHandler(tornado.web.RequestHandler):
         self.statsd = self.application.settings.get('statsd', NotImplemented)
 
         # mail client
-        # _smtp_config = self.application.settings.get('smtp')
-        #
+        _smtp_config = self.application.settings.get('smtp')
         if _smtp_config:
             self.smtp = MailClient2(_smtp_config)
         else:
